==> haskell-exact-pi-0.5.0.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-exact-pi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 exact-pi
version:              0.5.0.1
visibility:           public
id:                   exact-pi-0.5.0.1-F72AUKE6nbWACVe0pGslO7
key:                  exact-pi-0.5.0.1-F72AUKE6nbWACVe0pGslO7
license:              MIT
maintainer:           douglas.mcclean@gmail.com
author:               Douglas McClean
homepage:             https://github.com/dmcclean/exact-pi/
synopsis:             Exact rational multiples of pi (and integer powers of pi)
description:
    Provides an exact representation for rational multiples of pi alongside an approximate representation of all reals.
    Useful for storing and computing with conversion factors between physical units.

category:             Data
abi:                  d02da2c0cf2b75fe6b532d9fce8def69
exposed:              True
exposed-modules:      Data.ExactPi Data.ExactPi.TypeLevel
import-dirs:          /usr/lib/ghc-9.0.1/site-local/exact-pi-0.5.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/exact-pi-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/exact-pi-0.5.0.1
hs-libraries:         HSexact-pi-0.5.0.1-F72AUKE6nbWACVe0pGslO7
depends:
    base-4.15.0.0 numtype-dk-0.5.0.3-7lVEGdJa26cJWxGWph4a6r

haddock-interfaces:   /usr/share/doc/haskell-exact-pi/html/exact-pi.haddock
haddock-html:         /usr/share/doc/haskell-exact-pi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-exact-pi-0.5.0.1-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-exact-pi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 exact-pi
version:              0.5.0.1
visibility:           public
id:                   exact-pi-0.5.0.1-HHjKDyC1m6r801cISUXALQ
key:                  exact-pi-0.5.0.1-HHjKDyC1m6r801cISUXALQ
license:              MIT
maintainer:           douglas.mcclean@gmail.com
author:               Douglas McClean
homepage:             https://github.com/dmcclean/exact-pi/
synopsis:             Exact rational multiples of pi (and integer powers of pi)
description:
    Provides an exact representation for rational multiples of pi alongside an approximate representation of all reals.
    Useful for storing and computing with conversion factors between physical units.

category:             Data
abi:                  4885568003ad06d1047b3061c2a229da
exposed:              True
exposed-modules:      Data.ExactPi Data.ExactPi.TypeLevel
import-dirs:          /usr/lib/ghc-9.0.1/site-local/exact-pi-0.5.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/exact-pi-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/exact-pi-0.5.0.1
hs-libraries:         HSexact-pi-0.5.0.1-HHjKDyC1m6r801cISUXALQ
depends:
    base-4.15.0.0 numtype-dk-0.5.0.3-7lVEGdJa26cJWxGWph4a6r

haddock-interfaces:   /usr/share/doc/haskell-exact-pi/html/exact-pi.haddock
haddock-html:         /usr/share/doc/haskell-exact-pi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
